#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_THOUSAND_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_THOUSAND_HPP_INCLUDED

#include <boost/simd/constant/include/constants/thousand.hpp>

#endif
